@@ -11,6 +11,8 @@
 #include <stdlib.h>
 
 #include <QApplication>
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QFileDialog>
 #include <QProcess>
 #include <QQuickItem>
@@ -31,12 +33,14 @@
 #define XK_XKB_KEYS
 #include <X11/keysymdef.h>
 
+#include "kcmaccessibilityactivationgestures.h"
 #include "kcmaccessibilitybell.h"
 #include "kcmaccessibilitydata.h"
 #include "kcmaccessibilitykeyboard.h"
 #include "kcmaccessibilitykeyboardfilters.h"
 #include "kcmaccessibilitymouse.h"
 #include "kcmaccessibilityscreenreader.h"
+#include "kcmaccessibilityshakecursor.h"
 
 K_PLUGIN_FACTORY_WITH_JSON(KCMAccessFactory, "kcm_access.json", registerPlugin<KAccessConfig>(); registerPlugin<AccessibilityData>();)
 
@@ -142,7 +146,9 @@ KAccessConfig::KAccessConfig(QObject *parent, const KPluginMetaData &metaData)
     qmlRegisterAnonymousType<BellSettings>("org.kde.plasma.access.kcm", 0);
     qmlRegisterAnonymousType<KeyboardSettings>("org.kde.plasma.access.kcm", 0);
     qmlRegisterAnonymousType<KeyboardFiltersSettings>("org.kde.plasma.access.kcm", 0);
+    qmlRegisterAnonymousType<ActivationGesturesSettings>("org.kde.plasma.access.kcm", 0);
     qmlRegisterAnonymousType<ScreenReaderSettings>("org.kde.plasma.access.kcm", 0);
+    qmlRegisterAnonymousType<ShakeCursorSettings>("org.kde.plasma.access.kcm", 0);
 
     int tryOrcaRun = QProcess::execute(QStringLiteral("orca"), {QStringLiteral("--version")});
     m_screenReaderInstalled = tryOrcaRun != -2;
@@ -151,9 +157,11 @@ KAccessConfig::KAccessConfig(QObject *parent, const KPluginMetaData &metaData)
 
     connect(m_data->bellSettings(), &BellSettings::configChanged, this, &KAccessConfig::bellIsDefaultsChanged);
     connect(m_data->mouseSettings(), &MouseSettings::configChanged, this, &KAccessConfig::mouseIsDefaultsChanged);
+    connect(m_data->activationGesturesSettings(), &MouseSettings::configChanged, this, &KAccessConfig::activationGesturesIsDefaultsChanged);
     connect(m_data->keyboardFiltersSettings(), &ScreenReaderSettings::configChanged, this, &KAccessConfig::keyboardFiltersIsDefaultsChanged);
     connect(m_data->keyboardSettings(), &ScreenReaderSettings::configChanged, this, &KAccessConfig::keyboardModifiersIsDefaultsChanged);
     connect(m_data->screenReaderSettings(), &ScreenReaderSettings::configChanged, this, &KAccessConfig::screenReaderIsDefaultsChanged);
+    connect(m_data->shakeCursorSettings(), &ShakeCursorSettings::configChanged, this, &KAccessConfig::shakeCursorIsDefaultsChanged);
 }
 
 KAccessConfig::~KAccessConfig()
@@ -188,6 +196,9 @@ void KAccessConfig::launchOrcaConfiguration()
 
 void KAccessConfig::save()
 {
+    const bool shakeCursorSaveNeeded = m_data->shakeCursorSettings()->findItem(QStringLiteral("ShakeCursor"))->isSaveNeeded();
+    const bool shakeCursorMagnificationSaveNeeded = m_data->shakeCursorSettings()->findItem(QStringLiteral("ShakeCursorMagnification"))->isSaveNeeded();
+
     KQuickManagedConfigModule::save();
 
     if (bellSettings()->systemBell() || bellSettings()->customBell() || bellSettings()->visibleBell()) {
@@ -201,6 +212,24 @@ void KAccessConfig::save()
     // turning a11y features off needs to be done by kaccess
     // so run it to clear any enabled features and it will exit if it should
     QProcess::startDetached(QStringLiteral("kaccess"), {});
+
+    if (shakeCursorSaveNeeded) {
+        QDBusMessage reloadMessage =
+            QDBusMessage::createMethodCall(QStringLiteral("org.kde.KWin"),
+                                           QStringLiteral("/Effects"),
+                                           QStringLiteral("org.kde.kwin.Effects"),
+                                           shakeCursorSettings()->shakeCursor() ? QStringLiteral("loadEffect") : QStringLiteral("unloadEffect"));
+        reloadMessage.setArguments({QStringLiteral("shakecursor")});
+        QDBusConnection::sessionBus().call(reloadMessage);
+    }
+    if (shakeCursorMagnificationSaveNeeded) {
+        QDBusMessage reconfigureMessage = QDBusMessage::createMethodCall(QStringLiteral("org.kde.KWin"),
+                                                                         QStringLiteral("/Effects"),
+                                                                         QStringLiteral("org.kde.kwin.Effects"),
+                                                                         QStringLiteral("reconfigureEffect"));
+        reconfigureMessage.setArguments({QStringLiteral("shakecursor")});
+        QDBusConnection::sessionBus().call(reconfigureMessage);
+    }
 }
 
 QString KAccessConfig::orcaLaunchFeedback() const
@@ -243,11 +272,21 @@ KeyboardFiltersSettings *KAccessConfig::keyboardFiltersSettings() const
     return m_data->keyboardFiltersSettings();
 }
 
+ActivationGesturesSettings *KAccessConfig::activationGesturesSettings() const
+{
+    return m_data->activationGesturesSettings();
+}
+
 ScreenReaderSettings *KAccessConfig::screenReaderSettings() const
 {
     return m_data->screenReaderSettings();
 }
 
+ShakeCursorSettings *KAccessConfig::shakeCursorSettings() const
+{
+    return m_data->shakeCursorSettings();
+}
+
 bool KAccessConfig::bellIsDefaults() const
 {
     return bellSettings()->isDefaults();
@@ -268,10 +307,20 @@ bool KAccessConfig::keyboardModifiersIsDefaults() const
     return keyboardSettings()->isDefaults();
 }
 
+bool KAccessConfig::activationGesturesIsDefaults() const
+{
+    return activationGesturesSettings()->isDefaults();
+}
+
 bool KAccessConfig::screenReaderIsDefaults() const
 {
     return screenReaderSettings()->isDefaults();
 }
 
+bool KAccessConfig::shakeCursorIsDefaults() const
+{
+    return shakeCursorSettings()->isDefaults();
+}
+
 #include "kcmaccess.moc"
 #include "moc_kcmaccess.cpp"
