@@ -37,13 +37,14 @@
 
 #include "helper.h"
 
+using namespace Qt::StringLiterals;
+
 Dtime::Dtime(QWidget *parent, bool haveTimeDated)
     : QWidget(parent)
     , m_haveTimedated(haveTimeDated)
 {
     setupUi(this);
 
-    connect(setDateTimeAuto, &QCheckBox::toggled, this, &Dtime::serverTimeCheck);
     connect(setDateTimeAuto, &QCheckBox::toggled, this, &Dtime::configChanged);
 
     timeServerList->setEditable(false);
@@ -71,7 +72,7 @@ Dtime::Dtime(QWidget *parent, bool haveTimeDated)
 
     kclock = new Kclock(timeBox);
     kclock->setObjectName(QStringLiteral("Kclock"));
-    kclock->setMinimumSize(150, 150);
+    kclock->setMinimumSize(200, 200);
     v2->addWidget(kclock);
 
     QHBoxLayout *v3 = new QHBoxLayout();
@@ -121,15 +122,6 @@ void Dtime::currentZone()
     }
 }
 
-void Dtime::serverTimeCheck()
-{
-    // Enable time and date if the ntp utility is missing
-    bool enabled = ntpUtility.isEmpty() || !setDateTimeAuto->isChecked();
-    cal->setEnabled(enabled);
-    timeEdit->setEnabled(enabled);
-    // kclock->setEnabled(enabled);
-}
-
 void Dtime::findNTPutility()
 {
     QByteArray envpath = qgetenv("PATH");
@@ -137,15 +129,14 @@ void Dtime::findNTPutility()
         envpath.remove(0, 1);
     }
 
-    QStringList path = {"/sbin", "/usr/sbin"};
+    QStringList path = {u"/sbin"_s, u"/usr/sbin"_s};
     if (!envpath.isEmpty()) {
         path += QFile::decodeName(envpath).split(QLatin1Char(':'));
     } else {
-        path += {"/bin", "/usr/bin"};
+        path += {u"/bin"_s, u"/usr/bin"_s};
     }
 
-    const auto possible_ntputilities = {"ntpdate", "rdate"};
-    for (const QString &possible_ntputility : possible_ntputilities) {
+    for (const QString &possible_ntputility : {u"ntpdate"_s, u"rdate"_s}) {
         ntpUtility = QStandardPaths::findExecutable(possible_ntputility, path);
         if (!ntpUtility.isEmpty()) {
             qDebug() << "ntpUtility = " << ntpUtility;
