@@ -9,6 +9,7 @@
 #pragma once
 
 #include <QAbstractTableModel>
+#include <SDL2/SDL_gamecontroller.h>
 
 class Gamepad;
 
@@ -19,8 +20,6 @@ class ButtonModel : public QAbstractTableModel
     Q_PROPERTY(Gamepad *device MEMBER m_device NOTIFY deviceChanged REQUIRED)
 
 public:
-    enum CustomRoles { ButtonStateRole = Qt::UserRole };
-
     explicit ButtonModel(QObject *parent = nullptr);
 
     int rowCount(const QModelIndex &) const override;
@@ -30,11 +29,13 @@ public:
 
     QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
 
-    QHash<int, QByteArray> roleNames() const override;
-
 Q_SIGNALS:
     void deviceChanged();
 
+private:
+    Q_SLOT void initDeviceButtons();
+
 private:
     Gamepad *m_device = nullptr;
+    QList<SDL_GameControllerButton> m_buttons;
 };
