@@ -8,10 +8,9 @@
 #include "x11_libinput_dummydevice.h"
 
 X11LibinputBackend::X11LibinputBackend(QObject *parent)
-    : X11Backend(parent)
+    : InputBackend(parent)
 {
-    m_mode = InputBackendMode::XLibinput;
-    m_device = new X11LibinputDummyDevice(this, m_dpy);
+    m_device = new X11LibinputDummyDevice(this, QX11Info::display());
 }
 
 bool X11LibinputBackend::applyConfig()
@@ -40,5 +39,26 @@ void X11LibinputBackend::kcmInit()
 
     getConfig();
     applyConfig();
-    X11Backend::kcmInit();
 }
+
+QString X11LibinputBackend::errorString() const
+{
+    return m_errorString;
+}
+
+int X11LibinputBackend::deviceCount() const
+{
+    return 1;
+}
+
+bool X11LibinputBackend::isAnonymousDevice() const
+{
+    return true;
+}
+
+QList<QObject *> X11LibinputBackend::getDevices() const
+{
+    return QList<QObject *>(1, m_device);
+}
+
+#include "moc_x11_libinput_backend.cpp"
