@@ -6,16 +6,14 @@
 
 #pragma once
 
-#include "x11_backend.h"
+#include "inputbackend.h"
 
 #include <QList>
 
-class X11LibinputBackend : public X11Backend
+class X11LibinputBackend : public InputBackend
 {
     Q_OBJECT
 
-    Q_PROPERTY(int deviceCount READ deviceCount CONSTANT)
-
 public:
     explicit X11LibinputBackend(QObject *parent = nullptr);
     ~X11LibinputBackend() = default;
@@ -26,19 +24,10 @@ public:
     bool getConfig() override;
     bool getDefaultConfig() override;
     bool isChangedConfig() const override;
-    QString errorString() const override
-    {
-        return m_errorString;
-    }
-
-    virtual int deviceCount() const override
-    {
-        return 1;
-    }
-    virtual QList<QObject *> getDevices() const override
-    {
-        return QList<QObject *>(1, m_device);
-    }
+    QString errorString() const override;
+    int deviceCount() const override;
+    bool isAnonymousDevice() const override;
+    QList<QObject *> getDevices() const override;
 
 private:
     QObject *m_device;
